/*
** Module   : WrappedResource.java
** Abstract : interface for objects that can be checked for validity
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- --------------------------Description---------------------------
** 001 GES 20051125   @23506 Provides an interface for objects that can
**                           be checked for validity.
** 002 CA  20090227   @41381 Added isUnknown method - returns true if the
**                           wrapped resource is unknown.
** 005 OM  20130304          Refactored isValid and isUnknown of WrappedResource to valid 
**                           and unknown.
*/

package com.goldencode.p2j.util;

/**
 * An API for objects that can be checked for validity.
 */
public interface WrappedResource
{
   /**
    * Reports if this object is valid for use.  
    *
    * @return   <code>true</code> if we are valid (can be used).
    */
   public boolean valid();
   
   /**
    * Reports if this object is unknown.  
    *
    * @return   <code>true</code> if object is unknown.
    */
   public boolean unknown();
}
